@@ -18,7 +18,7 @@ from pyntcloud import PyntCloud
 import ot
 from multipoles import MultipoleExpansion
 
-def get_border_dict(labels,states=None,radius=10,state_ids=None,vdist=None,return_nnindex=True,return_nnvector=True,return_curvature=True,nn_states=None,scale=None,**border_args):
+def get_border_dict(labels,states=None,radius=10,state_ids=None,vdist=None,return_nnindex=True,return_nnvector=True,return_curvature=True,nn_states=None,scale=None,verbose=False,**border_args):
     """
     Computes the border properties of labeled regions in a segmented image.
 
@@ -143,11 +143,13 @@ def get_border_dict(labels,states=None,radius=10,state_ids=None,vdist=None,retur
             stateset=np.unique(states)
             for istate in stateset:
                 inds_states[istate]=np.where(border_dict['states']==istate)[0]
-                print(f'\rstate {istate} assigned {inds_states[istate].size}           ',end="")
+                if verbose:
+                    print(f'\rstate {istate} assigned {inds_states[istate].size}           ',end="")
                 #if inds_states[istate].size>0:
                     #knn_states[istate] = sklearn.neighbors.NearestNeighbors(n_neighbors=1, radius=1.,algorithm='ball_tree').fit(border_pts[inds_states[istate]])
             for i in iset:
-                print(f'\rgetting nn points for cell {i}                  ',end="")
+                if verbose:
+                    print(f'\rgetting nn points for cell {i}                  ',end="")
                 indi=inds_labels[i]
                 if indi is not None:
                     for istate in stateset:
@@ -174,7 +176,8 @@ def get_border_dict(labels,states=None,radius=10,state_ids=None,vdist=None,retur
         iset=iset[iset>0]
         for i in iset:
             msk=labels==i
-            print(f'\rgetting surface normals for label {i}, pixels {np.sum(msk)}          ',end="")
+            if verbose:
+                print(f'\rgetting surface normals for label {i}, pixels {np.sum(msk)}          ',end="")
             indi=np.where(border_index==i)[0]
             if indi.size>8:
                 border_pts_i,n_i,c_i=get_surface_points(msk,return_normals=True,return_curvature=True)
@@ -190,7 +193,7 @@ def get_border_dict(labels,states=None,radius=10,state_ids=None,vdist=None,retur
         border_dict['vdist']=vdist_border
     return border_dict
 
-def get_surface_points(msk,return_normals=False,return_curvature=False,knn=20,rscale=.1):
+def get_surface_points(msk,return_normals=False,return_curvature=False,knn=20,rscale=.1,verbose=False):
     """
     Computes the surface points of a labeled mask and optionally calculates normals and curvature.
 
@@ -245,7 +248,8 @@ def get_surface_points(msk,return_normals=False,return_curvature=False,knn=20,rs
     npts=border_pts.shape[0]
     if knn>int(npts/4):
         knn=int(npts/4)
-        print(f'adjusted knn: {knn} npts: {npts}')
+        if verbose:
+            print(f'adjusted knn: {knn} npts: {npts}')
     if return_normals or return_curvature:
         if msk.ndim==3:
             rand_dx=np.array([np.random.normal(loc=0.,scale=rscale,size=npts),np.random.normal(loc=0.,scale=rscale,size=npts),np.random.normal(loc=0.,scale=rscale,size=npts)]).T
